@@ -10,6 +10,7 @@ from ..property import Property
 from ..frame import Frame as ScomFrame
 from ..defines import *
 from .common.paramproxycontainer import ParamProxyContainer
+from ..exception import ReadException, WriteException
 
 
 # Links:
@@ -203,9 +204,13 @@ class ScomDevice(object):
                 value_size = response_frame.response_value_size()
                 value = response_frame[24:24 + value_size]
             else:
-                self.log.warning(u'Response frame not valid!')
+                msg = 'Response frame not valid!'
+                self.log.warning(msg)
+                raise WriteException(msg)
         else:
-            self.log.warning(u'Request frame not valid!')
+            msg = 'Request frame not valid!'
+            self.log.warning(msg)
+            raise WriteException(msg)
 
         return value
 
@@ -254,7 +259,9 @@ class ScomDevice(object):
         if success and value is not None:
             returned_value = value
         else:
-            self.log.warning('Could not read parameter \'%s\'' % param_info['name'])
+            msg = 'Could not read parameter \'%s\'' % param_info['name']
+            self.log.warning(msg)
+            raise ReadException(msg)
 
         return returned_value
 
@@ -280,11 +287,17 @@ class ScomDevice(object):
                     value_size = response_frame.response_value_size()
                     value = response_frame[24:24 + value_size]
                 elif response_frame.is_data_error_flag_set():
-                    self.log.warning('Warning: Error flag set in response frame!')
+                    msg = 'Error flag set in response frame!'
+                    self.log.warning(msg)
+                    raise ReadException(msg)
             else:
-                self.log.warning('No response frame received!')
+                msg = 'No response frame received!'
+                self.log.warning(msg)
+                raise ReadException(msg)
         else:
-            self.log.warning('Request frame not valid')
+            msg = 'Request frame not valid'
+            self.log.warning(msg)
+            ReadException(msg)
 
         return value
 
@@ -337,11 +350,17 @@ class ScomDevice(object):
                     value_size = response_frame.response_value_size()
                     value = response_frame[24:24 + value_size]
                 elif response_frame.is_data_error_flag_set():
-                    self.log.warning('Warning: Error flag set in response frame!')
+                    msg = 'Error flag set in response frame!'
+                    self.log.warning(msg)
+                    raise ReadException(msg)
             else:
-                self.log.warning('No response frame received!')
+                msg = 'No response frame received!'
+                self.log.warning(msg)
+                raise ReadException(msg)
         else:
-            self.log.warning('Request frame not valid')
+            msg = 'Request frame not valid'
+            self.log.warning(msg)
+            ReadException(msg)
 
         return value
 
@@ -369,9 +388,11 @@ class ScomDevice(object):
                 elif length == 4:
                     value = struct.unpack('L', value[0:4])[0]
             else:
-                assert False
+                assert False    # Support for given type not supported yet!
 
             return value
         else:
-            self.log.warning('Could not read user info \'%s\'' % user_info['name'])
+            msg = 'Could not read user info \'%s\'' % user_info['name']
+            self.log.warning(msg)
+            raise ReadException(msg)
             return default_value
